@@ -29,6 +29,7 @@ typedef struct _mrph2_t {
 #ifdef VGRAM
     char	*base;
     char	*pron;
+    char	*comp;
 #endif
     short	base_length;
 
@@ -93,6 +94,7 @@ extern int Undef_info_num;
 extern int Lang_j, Lang_e;
 extern char *Bos_string;
 extern char *Eos_string;
+extern int Output_compo;
 
 /*
  * functions
