@@ -253,6 +253,7 @@ static int register_undef_mrph1(target, mrph_idx, undef_len, no)
 #ifdef VGRAM
     mrph->base = "";
     mrph->pron = "";
+    mrph->comp = "\n";
 #endif
 
     mrph->hinsi = Undef_info[no].hinsi;
@@ -289,7 +290,7 @@ static int register_undef_mrph(target, mrph_idx, undef_len)
 
 /***********************************************************************
  * get_mrph_data
-***********************************************************************/
+ ***********************************************************************/
 #ifdef VGRAM
 #define DELI_MIDASI '\0'
 #define DELI_YOMI '\0'
@@ -306,6 +307,9 @@ void get_mrph_data(mrph, pbuf, target)
 
     p = pbuf;
 
+    mrph->midasi = target;
+    mrph->is_undef = 0;
+
     /* ФĹ */
     for (i = 0; *p++ != DELI_MIDASI; i++);
     mrph->base_length = mrph->length = i;
@@ -386,8 +390,11 @@ void get_mrph_data(mrph, pbuf, target)
     /* ̣ */
     mrph->info = p;
 
-    mrph->midasi = target;
-    mrph->is_undef = 0;
+#ifdef VGRAM
+    p = strchr(p, DELI_YOMI) + 1;
+    /* ʣ */
+    mrph->comp = p;
+#endif
 }
 
 /***********************************************************************
@@ -747,7 +754,9 @@ static int check_connect(pos, m_num, p_idx)
 	    Path[Path_num].end = pos + new_mrph->length;
 	    Path[Path_num].path = new_path;
 #ifdef DEBUG
-	    printf("[p:%d,prev:%d,m:%d,c:%d,pc:%d]\n",
+	    printf("%3d %3d %5d [p:%d,prev:%d,m:%d,c:%d,pc:%d]\n",
+		   Path[Path_num].start, Path[Path_num].end,
+		   Path[Path_num].state,
 		   Path_num,Path[Path_num].path[0],m_num,pcost[0].cost[i],Path[Path_num].cost);
 #endif
 	    if (++Path_num % PATH_NUM == 0 && malloc_path())
@@ -765,6 +774,7 @@ static void set_mrph_end(mrph)
     mrph->midasi = mrph->yomi = mrph->info = "";
 #ifdef VGRAM
     mrph->base = mrph->pron = "";
+    mrph->comp = "\n";
 #endif
     mrph->base_length = mrph->length = 3;
 
